/*
 *         Progetto: Mostra video (Autenticazione mediante database)
 *
 *           Autore: Roberto Fuligni
 *  Ultima modifica: 08/03/2022
 *
 *      Descrizione: Servizio di visualizzazione video riservato a utenti registrati.
 *                   I dati necessari all'autenticazione sono prelevati da un
 *                   database SQL mediante JDBC.
 */

CREATE DATABASE IF NOT EXISTS dbvideo
    CHARACTER SET = 'utf8'
    COLLATE = 'utf8_unicode_ci';

USE dbvideo;

DROP TABLE IF EXISTS video_utenti;
CREATE TABLE video_utenti
(
    username      VARCHAR(20)   NOT NULL PRIMARY KEY,
    salt          VARCHAR(32)   NOT NULL,
    password_hash VARCHAR(64)   NOT NULL,
    cognome       NVARCHAR(50)  NOT NULL,
    nome          NVARCHAR(50)  NOT NULL
);

DROP PROCEDURE IF EXISTS video_nuovoutente;
DELIMITER //
CREATE PROCEDURE video_nuovoutente(
    param_username VARCHAR(20),
    param_password VARCHAR(20),
    param_cognome NVARCHAR(50),
    param_nome NVARCHAR(50)
)
DETERMINISTIC
BEGIN
    SET @s = MD5(RAND());
    SET @h = SHA2(CONCAT(@s, param_password), 256);
    INSERT INTO video_utenti(username, salt, password_hash, cognome, nome)
    VALUES (param_username, @s, @h, param_cognome, param_nome);
END //
DELIMITER ;

CALL video_nuovoutente('rossi', 'pwrossi', 'Rossi', 'Mario');
CALL video_nuovoutente('verdi', 'pwverdi', 'Verdi', 'Carla');
CALL video_nuovoutente('neri', 'pwneri', 'Neri', 'Giacomo');
