/*
 *         Progetto: Mostra video (Autenticazione mediante database)
 *
 *           Autore: Roberto Fuligni
 *  Ultima modifica: 08/03/2022
 *
 *      Descrizione: Servizio di visualizzazione video riservato a utenti registrati.
 *                   I dati necessari all'autenticazione sono prelevati da un
 *                   database SQL mediante JDBC.
 */

package edu.fauser.netlab.mostravideo;

import javax.servlet.*;
import javax.servlet.annotation.*;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.IOException;
import java.net.URLEncoder;

@WebFilter(filterName = "AuthFilter", value = "/download")
public class AuthFilter implements Filter {
    public void destroy() {
    }

    public void doFilter(ServletRequest req, ServletResponse resp, FilterChain chain) throws ServletException, IOException {
        HttpServletRequest request = (HttpServletRequest) req;
        HttpServletResponse response = (HttpServletResponse) resp;
        HttpSession sessione = request.getSession(false);
        boolean autenticato = sessione != null && sessione.getAttribute("nomecompleto") != null;

        if (autenticato == false) {
            String dest = request.getRequestURI();
            if (request.getQueryString() != null)
                dest += "?" + request.getQueryString();

            String r = String.format("%s/login.jsp?redirect=%s",
                    request.getContextPath(),
                    URLEncoder.encode(dest, "utf-8")
            );
            response.sendRedirect(r);
        } else {
            chain.doFilter(req, resp);
        }
    }

    public void init(FilterConfig config) throws ServletException {
    }
}
