/*
 *         Progetto: Mostra video (Autenticazione mediante database)
 *
 *           Autore: Roberto Fuligni
 *  Ultima modifica: 08/03/2022
 *
 *      Descrizione: Servizio di visualizzazione video riservato a utenti registrati.
 *                   I dati necessari all'autenticazione sono prelevati da un
 *                   database SQL mediante JDBC.
 */

package edu.fauser.netlab.mostravideo;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.annotation.*;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.nio.file.Paths;

@WebServlet(name = "DownloadServlet", value = "/download")
public class DownloadServlet extends HttpServlet {
    protected void doPost(javax.servlet.http.HttpServletRequest request, javax.servlet.http.HttpServletResponse response) throws javax.servlet.ServletException, IOException {

    }

    protected void doGet(javax.servlet.http.HttpServletRequest request, javax.servlet.http.HttpServletResponse response) throws javax.servlet.ServletException, IOException {
        String video = request.getParameter("video");
        if (video != null) {
            video = Paths.get(video).getFileName().toString();      // Rimuove eventuali directory
            inviaVideo(request, response, video);
        }
    }

    private void inviaVideo(HttpServletRequest request, HttpServletResponse response, String nomeVideo) {
        ServletContext context = request.getServletContext();
        String videoDir = context.getRealPath("/WEB-INF/video");
        File file = new File(String.format("%s/%s", videoDir, nomeVideo));

        try {
            FileInputStream fis = new FileInputStream(file);
            ServletContext ctx = getServletContext();
            String mimeType = ctx.getMimeType(file.getAbsolutePath());

            response.setContentType(mimeType != null ? mimeType:"application/octet-stream");
            response.setContentLength((int) file.length());

            ServletOutputStream os = null;
            os = response.getOutputStream();
            byte[] bufferData = new byte[4096];
            int read;
            while((read = fis.read(bufferData)) != -1){
                os.write(bufferData, 0, read);
            }
            os.flush();
            os.close();
            fis.close();
        } catch (FileNotFoundException e) {
            response.setStatus(HttpServletResponse.SC_CONFLICT);
        } catch (IOException e) {
            response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
        }
    }
}
