/*
 *         Progetto: Mostra video (Autenticazione mediante database)
 *
 *           Autore: Roberto Fuligni
 *  Ultima modifica: 08/03/2022
 *
 *      Descrizione: Servizio di visualizzazione video riservato a utenti registrati.
 *                   I dati necessari all'autenticazione sono prelevati da un
 *                   database SQL mediante JDBC.
 */
package edu.fauser.netlab.mostravideo;

import edu.fauser.DbUtility;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.annotation.*;
import java.io.IOException;
import java.net.URLEncoder;
import java.sql.*;

@WebServlet(name = "LoginServlet", value = "/login")
public class LoginServlet extends HttpServlet {
    public void init(ServletConfig config) throws ServletException {
        super.init(config);
        // Impostazione dei parametri di configurazione per l'accesso
        // al database Mariadb "dbvideo" con pool di 2 connessioni
        // La classe edu.fauser.DbUtility è utilizzabile anche per il
        // collegamento ai database di Labs3.

        DbUtility dbu = DbUtility.getInstance(getServletContext());
        dbu.setDevCredentials("jdbc:mariadb://localhost:3306/dbvideo?maxPoolSize=2&pool", "root", "");
        dbu.setProdCredentials("jdbc:mariadb://localhost:3306/db123?maxPoolSize=2&pool", "db123", "***");
    }

    protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        boolean esci = request.getParameter("esci") != null;
        if (esci)
            eseguiLogout(request, response);
        else
            eseguiLogin(request, response);
    }

    protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
    }

    private void eseguiLogin(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        HttpSession sessione = request.getSession(false);
        if (sessione != null && sessione.getAttribute("nomecompleto") != null) {
            response.sendRedirect(request.getContextPath());
            return;
        }

        String user = request.getParameter("username");
        String pwd = request.getParameter("password");
        String redirect = request.getParameter("redirect");
        if (redirect == null || redirect.isEmpty())
            redirect = request.getContextPath();

        DbUtility dbu = DbUtility.getInstance(getServletContext());
        String urlDb = dbu.getUrl();
        String userDb = dbu.getUser();
        String passwordDb = dbu.getPassword();

        try (Connection cn = DriverManager.getConnection(urlDb, userDb, passwordDb)) {
            String strSql = "SELECT cognome, nome FROM video_utenti " +
                    "WHERE username = ? AND SHA2(CONCAT(salt, ?), 256) = password_hash";
            try (PreparedStatement ps = cn.prepareStatement(strSql)) {
                ps.setString(1, user);
                ps.setString(2, pwd);
                ResultSet rs = ps.executeQuery();
                if (rs.next() == true) {
                    String cognome = rs.getString("cognome").toUpperCase();
                    String nome = rs.getString("nome");
                    String nomeCompleto = String.format("%s %s", nome, cognome);

                    sessione = request.getSession(true);
                    sessione.setAttribute("nomecompleto", nomeCompleto);
                    sessione.setMaxInactiveInterval(30*60);      // 30 minuti
                    response.sendRedirect(redirect);
                } else {
                    String url = String.format("%s/login.jsp?errore&redirect=%s",
                            request.getContextPath(),
                            URLEncoder.encode(redirect, "utf-8")
                    );
                    response.sendRedirect(url);
                }
            }
        } catch (SQLException e) {
            response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
    }

    private void eseguiLogout(HttpServletRequest request, HttpServletResponse response) throws IOException {
        HttpSession session = request.getSession(false);
        String nc = (String) session.getAttribute("nomecompleto");
        if (nc != null) {
            session.invalidate();
        }
        response.sendRedirect(request.getContextPath());
    }
}
